@@ -1,8 +1,8 @@
 """A base class for extraction, transformation, and loading of data."""
 from abc import ABC, abstractmethod
-from typing import Dict, Optional, List
-from gene.database import AbstractDatabase
-from gene import ITEM_TYPES, SEQREPO_ROOT_DIR
+from typing import Optional, List
+from gene.database import Database
+from gene import PREFIX_LOOKUP, ITEM_TYPES, SEQREPO_DATA_PATH
 from biocommons.seqrepo import SeqRepo
 from pathlib import Path
 from ftplib import FTP
@@ -13,7 +13,7 @@ from dateutil import parser
 import datetime
 import logging
 import pydantic
-from gene.schemas import Gene, MatchType, SourceName
+from gene.schemas import Gene, MatchType
 
 logger = logging.getLogger('gene')
 logger.setLevel(logging.DEBUG)
@@ -22,18 +22,18 @@ logger.setLevel(logging.DEBUG)
 class Base(ABC):
     """The ETL base class."""
 
-    def __init__(self, database: AbstractDatabase, host: str, data_dir: str,
-                 src_data_dir: Path, seqrepo_dir: Path = SEQREPO_ROOT_DIR,
+    def __init__(self, database: Database, host: str, data_dir: str,
+                 src_data_dir: Path,
+                 seqrepo_dir=SEQREPO_DATA_PATH,
                  *args, **kwargs) -> None:
         """Instantiate Base class.
 
-        :param database: database instance
-        :param host: Hostname of FTP site
-        :param data_dir: Data directory of FTP site to look at
-        :param src_data_dir: Data directory for source
-        :param seqrepo_dir: Path to seqrepo directory
+        :param Database database: DynamoDB database
+        :param str host: Hostname of FTP site
+        :param str data_dir: Data directory of FTP site to look at
+        :param Path src_data_dir: Data directory for source
+        :param Path seqrepo_dir: Path to seqrepo directory
         """
-        self._src_name = SourceName(self.__class__.__name__)
         self._database = database
         self._host = host
         self._data_dir = data_dir
@@ -43,7 +43,7 @@ class Base(ABC):
 
     @abstractmethod
     def perform_etl(self) -> List[str]:
-        """Extract, Transform, and Load data into database.
+        """Extract, Transform, and Load data into DynamoDB database.
 
         :return: Concept IDs of concepts successfully loaded
         """
@@ -61,20 +61,36 @@ class Base(ABC):
 
     @abstractmethod
     def _add_meta(self, *args, **kwargs) -> None:
-        """Add source meta to database source info."""
+        """Add source meta to DynamoDB table."""
         raise NotImplementedError
 
-    def _create_data_directory(self) -> None:
+    def _create_data_directory(self):
         """Create data directory for source."""
         self.src_data_dir.mkdir(exist_ok=True, parents=True)
 
-    def _load_gene(self, gene: Dict) -> None:
-        """Load a gene record into database. This method takes responsibility for:
-         * validating structure correctness
-         * removing duplicates from list-like fields
-         * removing empty fields
+    def _load_meta(self, db, metadata, source_name) -> None:
+        """Load source metadata into database.
 
-        :param gene: Gene record
+        :param Database db: DynamoDB Database
+        :param SourceMeta metadata: Source's metadata
+        :param str source_name: Source to load metadata for
+        """
+        db.metadata.put_item(Item={
+            'src_name': source_name,
+            'data_license': metadata.data_license,
+            'data_license_url': metadata.data_license_url,
+            'version': metadata.version,
+            'data_url': metadata.data_url,
+            'rdp_url': metadata.rdp_url,
+            'data_license_attributes': metadata.data_license_attributes,
+            'genome_assemblies': metadata.genome_assemblies
+        })
+
+    def _load_gene(self, gene, batch) -> None:
+        """Load a gene record into database.
+
+        :param dict gene: Gene record
+        :param BatchWriter batch: Object to write data to DynamoDB
         """
         try:
             assert Gene(match_type=MatchType.NO_MATCH, **gene)
@@ -84,30 +100,41 @@ class Base(ABC):
         else:
             concept_id = gene['concept_id'].lower()
             gene['label_and_type'] = f"{concept_id}##identity"
-            gene["src_name"] = self._src_name.value
+            gene['src_name'] = \
+                PREFIX_LOOKUP[gene['concept_id'].split(':')[0].lower()]
             gene['item_type'] = 'identity'
 
-            for attr_type in ITEM_TYPES:
+            for attr_type, item_type in ITEM_TYPES.items():
                 if attr_type in gene:
                     value = gene[attr_type]
-                    if value is None or value == []:
+                    if value is not None and value != []:
+                        if isinstance(value, str):
+                            items = [value.lower()]
+                        else:
+                            gene[attr_type] = list(set(value))
+                            items = {item.lower() for item in value}
+                        for item in items:
+                            batch.put_item(Item={
+                                'label_and_type': f"{item}##{item_type}",
+                                'concept_id': concept_id,
+                                'src_name': gene['src_name'],
+                                'item_type': item_type
+                            })
+                    else:
                         del gene[attr_type]
-                    elif isinstance(value, str):
-                        continue
-                    gene[attr_type] = list(set(value))
-
-            self._database.add_record(gene, self._src_name)
+            batch.put_item(Item=gene)
             self._processed_ids.append(concept_id)
 
-    def _ftp_download(self, host: str, data_dir: str, fn: str, source_dir: Path,
+    def _ftp_download(self, host: str, data_dir: str, fn: str,
+                      source_dir: Path,
                       data_fn: str) -> Optional[str]:
         """Download data file from FTP site.
 
-        :param host: Source's FTP host name
-        :param data_dir: Data directory located on FTP site
-        :param fn: Filename for downloaded file
-        :param source_dir: Source's data directory
-        :param data_fn: Filename on FTP site to be downloaded
+        :param str host: Source's FTP host name
+        :param str data_dir: Data directory located on FTP site
+        :param str fn: Filename for downloaded file
+        :param Path source_dir: Source's data directory
+        :param str data_fn: Filename on FTP site to be downloaded
         :return: Time file was last updated
         """
         with FTP(host) as ftp:
@@ -124,10 +151,10 @@ class Base(ABC):
                            fn: str) -> None:
         """Download data file from FTP
 
-        :param ftp: FTP instance
-        :param data_fn: Filename on FTP site to be downloaded
-        :param source_dir: Source's data directory
-        :param fn: Filename for downloaded file
+        :param FTP ftp: FTP instance
+        :param str data_fn: Filename on FTP site to be downloaded
+        :param Path source_dir: Source's data directory
+        :param str fn: Filename for downloaded file
         """
         if data_fn.endswith('.gz'):
             filepath = source_dir / f'{fn}.gz'
@@ -141,10 +168,10 @@ class Base(ABC):
                     shutil.copyfileobj(f_in, f_out)
             remove(filepath)
 
-    def get_seqrepo(self, seqrepo_dir: Path) -> SeqRepo:
+    def get_seqrepo(self, seqrepo_dir) -> SeqRepo:
         """Return SeqRepo instance if seqrepo_dir exists.
 
-        :param seqrepo_dir: Path to seqrepo directory
+        :param Path seqrepo_dir: Path to seqrepo directory
         :return: SeqRepo instance
         """
         if not Path(seqrepo_dir).exists():
