@@ -1,7 +1,6 @@
 """This module defines GA4GH Chromosome Location."""
 import re
 import logging
-from typing import Dict, Optional
 
 from pydantic.error_wrappers import ValidationError
 
@@ -15,21 +14,20 @@ logger.setLevel(logging.DEBUG)
 class ChromosomeLocation:
     """The class for GA4GH Chromosome Location."""
 
-    def get_location(self, location: Dict, gene: Dict) -> Optional[Dict]:
+    def get_location(self, location, gene):
         """Transform a gene's location into a Chromosome Location.
 
-        :param location: A gene's location.
-        :param gene: A transformed gene record.
-        :return: If location is a valid VRS ChromosomeLocation, return a dictionary
-            containing the ChromosomeLocation. Else, return None.
+        :param dict location: A gene's location.
+        :param dict gene: A transformed gene record.
+        :return: If location is a valid VRS ChromosomeLocation, return a
+         dictionary containing the ChromosomeLocation.
+         Else, return None.
         """
-        if 'chr' in location and 'start' in location \
-                and 'end' in location:
+        if 'chr' in location and 'start' in location and 'end' in location:
             if location['start'] == 'p' and location['end'] == 'p':
                 location['start'] = 'pter'
                 location['end'] = 'cen'
-            elif location['start'] == 'q' and \
-                    location['end'] == 'q':
+            elif location['start'] == 'q' and location['end'] == 'q':
                 location['start'] = 'cen'
                 location['end'] = 'qter'
             try:
@@ -43,17 +41,17 @@ class ChromosomeLocation:
                 return chr_location
         return None
 
-    def set_interval_range(self, loc: str, arm_ix: int, location: Dict) -> None:
+    def set_interval_range(self, loc, arm_ix, location):
         """Set the location interval range.
 
-        :param loc: A gene location
-        :param arm_ix: The index of the q or p arm for a given location
-        :param location: A gene's location
+        :param str loc: A gene location
+        :param int arm_ix: The index of the q or p arm for a given location
+        :param dict location: A gene's location
         """
-        range_ix = re.search('-', loc).start()  # type: ignore
+        range_ix = re.search('-', loc).start()
 
         start = loc[arm_ix:range_ix]
-        start_arm_ix = re.search("[pq]", start).start()  # type: ignore
+        start_arm_ix = re.search("[pq]", start).start()
         start_arm = start[start_arm_ix]
 
         end = loc[range_ix + 1:]
@@ -64,7 +62,7 @@ class ChromosomeLocation:
             end = f"{start[0]}{end}"
             end_arm_match = re.search("[pq]", end)
 
-        end_arm_ix = end_arm_match.start()  # type: ignore
+        end_arm_ix = end_arm_match.start()
         end_arm = end[end_arm_ix]
 
         if (start_arm == end_arm and start > end) or \
